@@ -21,13 +21,13 @@ class Client(BaseClient):
     def cancel_withdrawal(self, id):
         """Makes a call to DELETE /api/1/withdrawals/{id}.
 
-        Cancel a withdrawal request. This can only be done if the request is still
-        in state <code>PENDING</code>.
+        Cancel a withdrawal request.
+        This can only be done if the request is still in state <code>PENDING</code>.
 
         Permissions required: <code>Perm_W_Withdrawals</code>
 
         :param id: ID of the withdrawal to cancel.
-        :type id: str
+        :type id: int
         """
         req = {
             'id': id,
@@ -37,14 +37,15 @@ class Client(BaseClient):
     def create_account(self, currency, name):
         """Makes a call to POST /api/1/accounts.
 
-        Create an additional account for the specified currency.
+        This request creates an Account for the specified currency.  Please note that the balances for the Account will be displayed based on the <code>asset</code> value, which is the currency the Account is based on.
 
         Permissions required: <code>Perm_W_Addresses</code>
 
-        :param currency: The currency code for the account you want to create
+        :param currency: The currency code for the Account you want to create.  Please see the Currency section for a detailed list of currencies supported by the Luno platform.
 
-                         You must be verified to trade currency in order to be able to create an
-                         account. A user has a limit of 4 accounts per currency.
+                         Users must be verified to trade currency in order to be able to create an Account.  For more information on the verification process, please see <a href="/help/en/articles/1000168396">How do I verify my identity?</a>.
+
+                         Users have a limit of 4 accounts per currency.
         :type currency: str
         :param name: The label to use for this account
         :type name: str
@@ -66,7 +67,7 @@ class Client(BaseClient):
 
         :param asset: Currency code of the asset.
         :type asset: str
-        :param name: An optional name for the new address
+        :param name: An optional name for the new Receive Address
         :type name: str
         """
         req = {
@@ -78,20 +79,17 @@ class Client(BaseClient):
     def create_quote(self, base_amount, pair, type, base_account_id=None, counter_account_id=None):
         """Makes a call to POST /api/1/quotes.
 
-        Creates a new quote to buy or sell a particular amount.
+        Creates a new quote to buy or sell a particular amount of a base currency for a counter currency.
 
-        You can specify either the exact amount that you want to pay or the exact
-        amount that you want too receive.
+        Users can specify either the exact amount to pay or the exact amount to receive.
 
-        For example, to buy exactly 0.1 Bitcoin using ZAR, you would create a quote
-        to BUY 0.1 XBTZAR. The returned quote includes the appropriate ZAR amount. To
-        buy Bitcoin using exactly ZAR 100, you would create a quote to SELL 100
-        ZARXBT. The returned quote specifies the Bitcoin as the counter amount that
-        will be returned.
+        For example, to buy exactly 0.1 Bitcoin using ZAR, you would create a quote to BUY 0.1 XBTZAR.
+        The returned quote includes the appropriate ZAR amount.
+        To buy Bitcoin using exactly ZAR 100, create a quote to SELL 100 ZARXBT.
+        The returned quote specifies the Bitcoin as the counter amount returned.
 
-        An error is returned if your account is not verified for the currency pair,
-        or if your account would have insufficient balance to ever exercise the
-        quote.
+        An error is returned if the Account is not verified for the currency pair,
+        or if the Account would have insufficient balance to ever exercise the quote.
 
         Permissions required: <code>Perm_W_Orders</code>
 
@@ -102,10 +100,10 @@ class Client(BaseClient):
         :type pair: str
         :param type: <code>BUY</code> or <code>SELL</code>.
         :type type: str
-        :param base_account_id: Optional account for the pair's base currency.
-        :type base_account_id: str
-        :param counter_account_id: Optional account for the pair's counter currency.
-        :type counter_account_id: str
+        :param base_account_id: Optional Account for the pair's base currency.
+        :type base_account_id: int
+        :param counter_account_id: Optional Account for the pair's counter currency.
+        :type counter_account_id: int
         """
         req = {
             'base_amount': base_amount,
@@ -116,22 +114,25 @@ class Client(BaseClient):
         }
         return self.do('POST', '/api/1/quotes', req=req, auth=True)
 
-    def create_withdrawal(self, amount, type, beneficiary_id=None, reference=None):
+    def create_withdrawal(self, amount, type, beneficiary_id=None, external_id=None, reference=None):
         """Makes a call to POST /api/1/withdrawals.
 
-        Creates a new withdrawal request.
+        Creates a new withdrawal request to the specified beneficiary.
 
         Permissions required: <code>Perm_W_Withdrawals</code>
 
-        :param amount: Amount to withdraw. The currency depends on the type.
+        :param amount: Amount to withdraw. The currency withdrawn depends on the type setting.
         :type amount: float
         :param type: Withdrawal type.
         :type type: str
-        :param beneficiary_id: The beneficiary ID of the bank account the withdrawal will be paid out
-                               to. This parameter is required if you have multiple bank accounts. Your
-                               bank account beneficiary ID can be found by clicking on the beneficiary
-                               name on the <a href="/wallet/beneficiaries">Beneficiaries</a> page.
-        :type beneficiary_id: str
+        :param beneficiary_id: The beneficiary ID of the bank account the withdrawal will be paid out to.
+                               This parameter is required if the user has set up multiple beneficiaries.
+                               The beneficiary ID can be found by selecting on the beneficiary name on the user’s <a href="/wallet/beneficiaries">Beneficiaries</a> page.
+        :type beneficiary_id: int
+        :param external_id: Optional unique ID to associate with this withdrawal.
+                            Useful to prevent duplicate sends.
+                            This field supports all alphanumeric characters including "-" and "_".
+        :type external_id: str
         :param reference: For internal use.
         :type reference: str
         """
@@ -139,6 +140,7 @@ class Client(BaseClient):
             'amount': amount,
             'type': type,
             'beneficiary_id': beneficiary_id,
+            'external_id': external_id,
             'reference': reference,
         }
         return self.do('POST', '/api/1/withdrawals', req=req, auth=True)
@@ -146,13 +148,13 @@ class Client(BaseClient):
     def discard_quote(self, id):
         """Makes a call to DELETE /api/1/quotes/{id}.
 
-        Discard a quote. Once a quote has been discarded, it cannot be exercised even
-        if it has not expired yet.
+        Discard a Quote.
+        Once a Quote has been discarded, it cannot be exercised even if it has not expired.
 
         Permissions required: <code>Perm_W_Orders</code>
 
         :param id: ID of the quote to discard.
-        :type id: str
+        :type id: int
         """
         req = {
             'id': id,
@@ -162,17 +164,16 @@ class Client(BaseClient):
     def exercise_quote(self, id):
         """Makes a call to PUT /api/1/quotes/{id}.
 
-        Exercise a quote to perform the trade. If there is sufficient balance
-        available in your account, it will be debited and the counter amount
-        credited.
+        Exercise a quote to perform the Trade.
+        If there is sufficient balance available in the Account,
+        it will be debited and the counter amount credited.
 
-        An error is returned if the quote has expired or if you have insufficient
-        available balance.
+        An error is returned if the quote has expired or if the Account has insufficient available balance.
 
         Permissions required: <code>Perm_W_Orders</code>
 
         :param id: ID of the quote to exercise.
-        :type id: str
+        :type id: int
         """
         req = {
             'id': id,
@@ -182,7 +183,7 @@ class Client(BaseClient):
     def get_balances(self, assets=None):
         """Makes a call to GET /api/1/balance.
 
-        Return the list of all accounts and their respective balances.
+        The list of all Accounts and their respective balances for the requesting user.
 
         Permissions required: <code>Perm_R_Balance</code>
 
@@ -198,8 +199,7 @@ class Client(BaseClient):
     def get_fee_info(self, pair):
         """Makes a call to GET /api/1/fee_info.
 
-        Returns your fees and 30 day trading volume (as of midnight) for a given
-        pair.
+        Returns the fees and 30 day trading volume (as of midnight) for a given currency pair.  For complete details, please see <a href="en/countries">Fees & Features</a>.
 
         Permissions required: <code>Perm_R_Orders</code>
 
@@ -215,17 +215,16 @@ class Client(BaseClient):
         """Makes a call to GET /api/1/funding_address.
 
         Returns the default receive address associated with your account and the
-        amount received via the address. You can specify an optional address
-        parameter to return information for a non-default receive address. In the
-        response, total_received is the total confirmed Bitcoin amount received
-        excluding unconfirmed transactions. total_unconfirmed is the total sum of
-        unconfirmed receive transactions.
+        amount received via the address. Users can specify an optional address parameter to return information for a non-default receive address.
+
+        In the response, <code>total_received</code> is the total confirmed amount received excluding unconfirmed transactions.
+        <code>total_unconfirmed</code> is the total sum of unconfirmed receive transactions.
 
         Permissions required: <code>Perm_R_Addresses</code>
 
         :param asset: Currency code of the asset.
         :type asset: str
-        :param address: Specific Bitcoin or Ethereum address to retrieve. If not provided, the
+        :param address: Specific cryptocurrency address to retrieve. If not provided, the
                         default address will be used.
         :type address: str
         """
@@ -235,10 +234,28 @@ class Client(BaseClient):
         }
         return self.do('GET', '/api/1/funding_address', req=req, auth=True)
 
+    def get_lightning_receive(self, id):
+        """Makes a call to GET /api/1/lightning/receive/{id}.
+
+        <b>Alpha warning!</b> The Lightning API is still in Alpha stage.
+        The risks are limited api availability and channel capacity.
+
+        Lookup the status of a Lightning Receive Invoice.
+
+        Permissions required: <code>Perm_W_Send</code>
+
+        :param id: ID of invoice.
+        :type id: int
+        """
+        req = {
+            'id': id,
+        }
+        return self.do('GET', '/api/1/lightning/receive/{id}', req=req, auth=True)
+
     def get_order(self, id):
         """Makes a call to GET /api/1/orders/{id}.
 
-        Get an order by its ID.
+        Get an Order's details by its ID.
 
         Permissions required: <code>Perm_R_Orders</code>
 
@@ -253,12 +270,15 @@ class Client(BaseClient):
     def get_order_book(self, pair):
         """Makes a call to GET /api/1/orderbook_top.
 
-        Returns a list of the top 100 bids and asks in the order book.
-        Ask orders are sorted by price ascending.
-        Bid orders are sorted by price descending.
+        Returns a list of the top 100 <em>bids</em> and <em>asks</em> for the currency pair specified in the Order Book.
+
+        Ask Orders are sorted by price ascending.
+
+        Bid Orders are sorted by price descending.
+
         Orders of the same price are aggregated.
 
-        :param pair: Currency pair
+        :param pair: Currency pair of the Orders to retrieve
         :type pair: str
         """
         req = {
@@ -269,15 +289,19 @@ class Client(BaseClient):
     def get_order_book_full(self, pair):
         """Makes a call to GET /api/1/orderbook.
 
-        Returns a list of all bids and asks in the order book.
+        This request returns a list of all <em>bids</em> and <em>asks</em> for the currency pair specified in the Order Book.
+
         Ask orders are sorted by price ascending.
+
         Bid orders are sorted by price descending.
+
         Multiple orders at the same price are not aggregated.
 
-        Warning: This may return a large amount of data. Generally you should rather
-        use GetOrderBook or the Streaming API.
+        <b>Warning:</b> This may return a large amount of data.
+        Users are recommended to use the <a href="#operation/getOrderBook">top 100 bids and asks</a>
+        or the <a href="#tag/streaming-API-(beta)">Streaming API</a>.
 
-        :param pair: Currency pair
+        :param pair: Currency pair of the Orders to retrieve
         :type pair: str
         """
         req = {
@@ -285,15 +309,32 @@ class Client(BaseClient):
         }
         return self.do('GET', '/api/1/orderbook', req=req, auth=False)
 
+    def get_order_v2(self, id):
+        """Makes a call to GET /api/exchange/2/orders/{id}.
+
+        Get the details for an order.<br>
+        This endpoint is in BETA, behaviour and specification may change without
+        any previous notice.
+
+        Permissions required: <code>Perm_R_Orders</code>
+
+        :param id: Order reference
+        :type id: str
+        """
+        req = {
+            'id': id,
+        }
+        return self.do('GET', '/api/exchange/2/orders/{id}', req=req, auth=True)
+
     def get_quote(self, id):
         """Makes a call to GET /api/1/quotes/{id}.
 
-        Get the latest status of a quote.
+        Get the latest status of a quote by its id.
 
         Permissions required: <code>Perm_R_Orders</code>
 
         :param id: ID of the quote to retrieve.
-        :type id: str
+        :type id: int
         """
         req = {
             'id': id,
@@ -303,7 +344,9 @@ class Client(BaseClient):
     def get_ticker(self, pair):
         """Makes a call to GET /api/1/ticker.
 
-        Returns the latest ticker indicators.
+        Returns the latest ticker indicators for the specified currency pair.
+
+        Please see the <a href="#tag/currency ">Currency list</a> for the complete list of supported currency pairs.
 
         :param pair: Currency pair
         :type pair: str
@@ -318,6 +361,8 @@ class Client(BaseClient):
 
         Returns the latest ticker indicators from all active Luno exchanges.
 
+        Please see the <a href="#tag/currency ">Currency list</a> for the complete list of supported currency pairs.
+
         """
         return self.do('GET', '/api/1/tickers', req=None, auth=False)
 
@@ -329,20 +374,30 @@ class Client(BaseClient):
         Permissions required: <code>Perm_R_Withdrawals</code>
 
         :param id: Withdrawal ID to retrieve.
-        :type id: str
+        :type id: int
         """
         req = {
             'id': id,
         }
         return self.do('GET', '/api/1/withdrawals/{id}', req=req, auth=True)
 
+    def list_beneficiaries_response(self):
+        """Makes a call to GET /api/1/beneficiaries.
+
+        Returns a list of bank beneficiaries.
+
+        Permissions required: <code>Perm_R_Beneficiaries</code>
+
+        """
+        return self.do('GET', '/api/1/beneficiaries', req=None, auth=True)
+
     def list_orders(self, created_before=None, limit=None, pair=None, state=None):
         """Makes a call to GET /api/1/listorders.
 
-        Returns a list of the most recently placed orders. You can specify an
-        optional <code>state=PENDING</code> parameter to restrict the results to only
-        open orders. You can also specify the market by using the optional pair
-        parameter. The list is truncated after 100 items.
+        Returns a list of the most recently placed Orders.
+        Users can specify an optional <code>state=PENDING</code> parameter to restrict the results to only open Orders.
+        Users can also specify the market by using the optional currency pair parameter.
+        The list is truncated after 100 items.
 
         Permissions required: <code>Perm_R_Orders</code>
 
@@ -363,18 +418,44 @@ class Client(BaseClient):
         }
         return self.do('GET', '/api/1/listorders', req=req, auth=True)
 
+    def list_orders_v2(self, created_before=None, limit=None, pair=None, status=None):
+        """Makes a call to GET /api/exchange/2/listorders.
+
+        Returns a list of the most recently placed orders. The list is truncated
+        after 100 items by default<br>
+        This endpoint is in BETA, behaviour and specification may change without
+        any previous notice.
+
+        Permissions required: <Code>Perm_R_Orders</Code>
+
+        :param created_before: Filter to orders created before this timestamp (Unix milliseconds)
+        :type created_before: int
+        :param limit: Limit to this many orders
+        :type limit: int
+        :param pair: Filter to only orders of this currency pair
+        :type pair: str
+        :param status: Filter to only orders of this status
+        :type status: str
+        """
+        req = {
+            'created_before': created_before,
+            'limit': limit,
+            'pair': pair,
+            'status': status,
+        }
+        return self.do('GET', '/api/exchange/2/listorders', req=req, auth=True)
+
     def list_pending_transactions(self, id):
         """Makes a call to GET /api/1/accounts/{id}/pending.
 
-        Return a list of all pending transactions related to the account.
+        Return a list of all transactions that have not completed for the Account.
 
-        Unlike account entries, pending transactions are not numbered, and may be
-        reordered, deleted or updated at any time.
+        Pending transactions are not numbered, and may be reordered, deleted or updated at any time.
 
         Permissions required: <code>Perm_R_Transactions</code>
 
         :param id: Account ID
-        :type id: str
+        :type id: int
         """
         req = {
             'id': id,
@@ -384,8 +465,10 @@ class Client(BaseClient):
     def list_trades(self, pair, since=None):
         """Makes a call to GET /api/1/trades.
 
-        Returns a list of the most recent trades. At most 100 results are returned
-        per call.
+        Returns a list of the most recent Trades for the specified currency pair in the last 24 hours.
+        At most 100 results are returned per call.
+
+        Please see the <a href="#tag/currency ">Currency list</a> for the complete list of supported currency pairs.
 
         :param pair: Currency pair
         :type pair: str
@@ -415,8 +498,8 @@ class Client(BaseClient):
 
         Permissions required: <code>Perm_R_Transactions</code>
 
-        :param id: Account ID
-        :type id: str
+        :param id: Account ID - the unique identifier for the specific Account.
+        :type id: int
         :param max_row: Maximum of the row range to return (exclusive)
         :type max_row: int
         :param min_row: Minimum of the row range to return (inclusive)
@@ -432,16 +515,13 @@ class Client(BaseClient):
     def list_user_trades(self, pair, after_seq=None, before=None, before_seq=None, limit=None, since=None, sort_desc=None):
         """Makes a call to GET /api/1/listtrades.
 
-        Returns a list of your recent trades for a given pair, sorted by oldest
-        first. If <code>before</code> is specified, then the trades are returned
-        sorted by most-recent first.
+        Returns a list of the recent Trades for a given currency pair for this user, sorted by oldest first.
+        If <code>before</code> is specified, then Trades are returned sorted by most-recent first.
 
-        <code>type</code> in the response indicates the type of order that you placed
-        in order to participate in the trade. Possible types: <code>BID</code>,
-        <code>ASK</code>.
+        <code>type</code> in the response indicates the type of Order that was placed to participate in the trade.
+        Possible types: <code>BID</code>, <code>ASK</code>.
 
-        If <code>is_buy</code> in the response is true, then the order which
-        completed the trade (market taker) was a bid order.
+        If <code>is_buy</code> in the response is true, then the Order which completed the trade (market taker) was a Bid Order.
 
         Results of this query may lag behind the latest data.
 
@@ -486,18 +566,17 @@ class Client(BaseClient):
         """
         return self.do('GET', '/api/1/withdrawals', req=None, auth=True)
 
-    def post_limit_order(self, pair, price, type, volume, base_account_id=None, counter_account_id=None, post_only=None):
+    def post_limit_order(self, pair, price, type, volume, base_account_id=None, counter_account_id=None, post_only=None, stop_direction=None, stop_price=None):
         """Makes a call to POST /api/1/postorder.
 
-        Create a new trade order.
+        Create a new Trade Order.
 
-        Warning! Orders cannot be reversed once they have executed. Please ensure
-        your program has been thoroughly tested before submitting orders.
+        <b>Warning!</b> Orders cannot be reversed once they have executed.
+        Please ensure your program has been thoroughly tested before submitting Orders.
 
-        If no <code>base_account_id</code> or <code>counter_account_id</code> are
-        specified, your default base currency or counter currency account will be
-        used. You can find your account IDs by calling the
-        <a href="#operation/getBalances">Balances</a> API.
+        If no <code>base_account_id</code> or <code>counter_account_id</code> are specified,
+        your default base currency or counter currency account will be used.
+        You can find your Account IDs by calling the <a href="#operation/getBalances">Balances</a> API.
 
         Permissions required: <code>Perm_W_Orders</code>
 
@@ -506,21 +585,32 @@ class Client(BaseClient):
         :param price: Limit price as a decimal string in units of ZAR/BTC.
         :type price: float
         :param type: <code>BID</code> for a bid (buy) limit order<br>
-                     <code>ASK</code> for ab ask (sell) limit order
+                     <code>ASK</code> for an ask (sell) limit order
         :type type: str
-        :param volume: Amount of Bitcoin or Ethereum to buy or sell as a decimal string in units
-                       of the currency.
+        :param volume: Amount of cryptocurrency to buy or sell as a decimal string in units of the currency.
         :type volume: float
-        :param base_account_id: The base currency account to use in the trade.
-        :type base_account_id: str
-        :param counter_account_id: The counter currency account to use in the trade.
-        :type counter_account_id: str
-        :param post_only: Post-only orders will be cancelled if they would otherwise have traded
-                          immediately. For example, if there's a bid at ZAR 100,000 and you place
-                          a post-only ask at ZAR 100,000, your order will be cancelled instead of
-                          trading. If the best bid is ZAR 100,000 and you place a post-only ask at
-                          ZAR 101,000, your order won't trade but will go into the order book.
+        :param base_account_id: The base currency Account to use in the trade.
+        :type base_account_id: int
+        :param counter_account_id: The counter currency Account to use in the trade.
+        :type counter_account_id: int
+        :param post_only: Post-only Orders will be cancelled if they would otherwise have traded
+                          immediately.
+                          For example, if there's a bid at ZAR 100,000 and you place a post-only ask at ZAR 100,000,
+                          your order will be cancelled instead of trading.
+                          If the best bid is ZAR 100,000 and you place a post-only ask at ZAR 101,000,
+                          your order won't trade but will go into the order book.
         :type post_only: bool
+        :param stop_direction: Side of the trigger price to activate the order. This should be set if `stop_price` is also
+                               set.
+
+                               `RELATIVE_LAST_TRADE` will automatically infer the direction based on the last
+                               trade price and the stop price. If last trade price is less than stop price then stop
+                               direction is ABOVE otherwise is BELOW.
+        :type stop_direction: str
+        :param stop_price: Trigger trade price to activate this order as a decimal string. If this
+                           is set then this is treated as a Stop Limit Order and `stop_direction`
+                           is expected to be set too.
+        :type stop_price: float
         """
         req = {
             'pair': pair,
@@ -530,41 +620,38 @@ class Client(BaseClient):
             'base_account_id': base_account_id,
             'counter_account_id': counter_account_id,
             'post_only': post_only,
+            'stop_direction': stop_direction,
+            'stop_price': stop_price,
         }
         return self.do('POST', '/api/1/postorder', req=req, auth=True)
 
     def post_market_order(self, pair, type, base_account_id=None, base_volume=None, counter_account_id=None, counter_volume=None):
         """Makes a call to POST /api/1/marketorder.
 
-        Create a new market order.
+        Create a new Market Order.
 
-        A market order executes immediately, and either buys as much Bitcoin or
-        Ethereum that can be bought for a set amount of fiat currency, or sells a
-        set amount of Bitcoin or Ethereum for as much fiat as possible.
+        A Market Order executes immediately, and either buys as much of the asset that can be bought for a set amount of fiat currency, or sells a set amount of the asset for as much as possible.
 
-        Warning! Orders cannot be reversed once they have executed. Please ensure
-        your program has been thoroughly tested before submitting orders.
+        <b>Warning!</b> Orders cannot be reversed once they have executed.
+        Please ensure your program has been thoroughly tested before submitting Orders.
 
-        If no base_account_id or counter_account_id are specified, your default base
-        currency or counter currency account will be used. You can find your account
-        IDs by calling the <a href="#operation/getBalances">Balances</a> API.
+        If no <code>base_account_id</code> or <code>counter_account_id</code> are specified, the default base currency or counter currency account will be used.
+        Users can find their account IDs by calling the <a href="#operation/getBalances">Balances</a> request.
 
         Permissions required: <code>Perm_W_Orders</code>
 
         :param pair: The currency pair to trade.
         :type pair: str
-        :param type: <code>BUY</code> to buy Bitcoin or Ethereum<br>
-                     <code>SELL</code> to sell Bitcoin or Ethereum
+        :param type: <code>BUY</code> to buy an asset<br>
+                     <code>SELL</code> to sell an asset
         :type type: str
         :param base_account_id: The base currency account to use in the trade.
-        :type base_account_id: str
-        :param base_volume: For a <code>SELL</code> order: amount of Bitcoin to sell as a decimal
-                            string in units of BTC or ETH.
+        :type base_account_id: int
+        :param base_volume: For a <code>SELL</code> order: amount of the base currency to use (e.g. how much BTC to sell for EUR in the BTC/EUR market)
         :type base_volume: float
         :param counter_account_id: The counter currency account to use in the trade.
-        :type counter_account_id: str
-        :param counter_volume: For a <code>BUY</code> order: amount of local currency (e.g. ZAR, MYR) to
-                               spend as a decimal string in units of the local currency.
+        :type counter_account_id: int
+        :param counter_volume: For a <code>BUY</code> order: amount of the counter currency to use (e.g. how much EUR to use to buy BTC in the BTC/EUR market)
         :type counter_volume: float
         """
         req = {
@@ -577,24 +664,48 @@ class Client(BaseClient):
         }
         return self.do('POST', '/api/1/marketorder', req=req, auth=True)
 
-    def send(self, address, amount, currency, description=None, message=None):
-        """Makes a call to POST /api/1/send.
+    def receive_lightning(self, amount, currency=None, description=None, expires_at=None):
+        """Makes a call to POST /api/1/lightning/receive.
 
-        Send Bitcoin from your account to a Bitcoin address or email address. Send
-        Ethereum from your account to an Ethereum address.
+        <b>Alpha warning!</b> The Lightning API is still in Alpha stage.
+        The risks are limited api availability and channel capacity.
 
-        If the email address is not associated with an existing Luno account, an
-        invitation to create an account and claim the funds will be sent.
-
-        Warning! Cryptocurrency transactions are irreversible. Please ensure your
-        program has been thoroughly tested before using this call.
+        Create a lightning invoice which can be used to receive
+        BTC payments over the lightning network.
 
         Permissions required: <code>Perm_W_Send</code>
 
-        :param address: Destination Bitcoin address or email address, or Ethereum address to send
-                        to.
+        :param amount: Amount to send as a decimal string.
+        :type amount: float
+        :param currency: Currency to receive (defaults to XBT).
+        :type currency: str
+        :param description: User defined description to add to lightning invoice.
+        :type description: str
+        :param expires_at: Unix expiry timestamp (ms).
 
-                        Note:
+                           in query
+        :type expires_at: int
+        """
+        req = {
+            'amount': amount,
+            'currency': currency,
+            'description': description,
+            'expires_at': expires_at,
+        }
+        return self.do('POST', '/api/1/lightning/receive', req=req, auth=True)
+
+    def send(self, address, amount, currency, description=None, destination_tag=None, external_id=None, has_destination_tag=None, message=None):
+        """Makes a call to POST /api/1/send.
+
+        Send assets from an Account. Please note that the asset type sent must match the receive address of the same cryptocurrency of the same type - Bitcoin to Bitcoin, Ethereum to Ethereum, etc.
+
+        Sends can be to a cryptocurrency receive address, or the email address of another Luno platform user.
+
+        Permissions required: <code>Perm_W_Send</code>
+
+        :param address: Destination address or email address.
+
+                        <b>Note</b>:
                         <ul>
                         <li>Ethereum addresses must be
                         <a href="https://github.com/ethereum/EIPs/blob/master/EIPS/eip-55.md" target="_blank" rel="nofollow">checksummed</a>.</li>
@@ -605,10 +716,18 @@ class Client(BaseClient):
         :type amount: float
         :param currency: Currency to send.
         :type currency: str
-        :param description: Description for the transaction to record on the account statement.
+        :param description: User description for the transaction to record on the account statement.
         :type description: str
-        :param message: Message to send to the recipient. This is only relevant when sending to
-                        an email address.
+        :param destination_tag: Optional XRP destination tag. Note that HasDestinationTag must be true if this value is provided.
+        :type destination_tag: int
+        :param external_id: Optional unique ID to associate with this withdrawal.
+                            Useful to prevent duplicate sends in case of failure.
+                            This supports all alphanumeric characters, as well as "-" and "_".
+        :type external_id: str
+        :param has_destination_tag: Optional boolean flag indicating that a XRP destination tag is provided (even if zero).
+        :type has_destination_tag: bool
+        :param message: Message to send to the recipient.
+                        This is only relevant when sending to an email address.
         :type message: str
         """
         req = {
@@ -616,18 +735,56 @@ class Client(BaseClient):
             'amount': amount,
             'currency': currency,
             'description': description,
+            'destination_tag': destination_tag,
+            'external_id': external_id,
+            'has_destination_tag': has_destination_tag,
             'message': message,
         }
         return self.do('POST', '/api/1/send', req=req, auth=True)
 
+    def send_lightning(self, payment_request, currency=None, description=None, external_id=None):
+        """Makes a call to POST /api/1/lightning/send.
+
+        <b>Alpha warning!</b> The Lightning API is still in Alpha stage.
+        The risks are limited api availability and channel capacity.
+
+        Send Bitcoin over the Lightning network from your Bitcoin Account.
+
+        Warning! Cryptocurrency transactions are irreversible. Please ensure your
+        program has been thoroughly tested before using this call.
+
+        Permissions required: <code>Perm_W_Send</code>
+
+        :param payment_request: Lightning payment request to send to.
+        :type payment_request: str
+        :param currency: Currency to send.
+        :type currency: str
+        :param description: Description for the transaction to record on the account statement.
+        :type description: str
+        :param external_id: Optional unique ID to associate with this withdrawal. Useful to prevent
+                            duplicate sends in case of failure. It supports all alphanumeric
+                            characters, as well as "-" and "_".
+        :type external_id: str
+        """
+        req = {
+            'payment_request': payment_request,
+            'currency': currency,
+            'description': description,
+            'external_id': external_id,
+        }
+        return self.do('POST', '/api/1/lightning/send', req=req, auth=True)
+
     def stop_order(self, order_id):
         """Makes a call to POST /api/1/stoporder.
 
-        Request to stop an order.
+        Request to stop an Order.
+
+        <b>Note!</b>: Once an Order has been completed, it can not be reversed.
+        The return value from this request will indicate if the Stop request was successful or not.
 
         Permissions required: <code>Perm_W_Orders</code>
 
-        :param order_id: The order reference as a string.
+        :param order_id: The Order identifier as a string.
         :type order_id: str
         """
         req = {
@@ -635,5 +792,23 @@ class Client(BaseClient):
         }
         return self.do('POST', '/api/1/stoporder', req=req, auth=True)
 
+    def update_account_name(self, id, name):
+        """Makes a call to PUT /api/1/accounts/{id}/name.
+
+        Update the name of an account with a given ID.
+
+        Permissions required: <code>Perm_W_Addresses</code>
+
+        :param id: Account ID - the unique identifier for the specific Account.
+        :type id: int
+        :param name: The label to use for this account
+        :type name: str
+        """
+        req = {
+            'id': id,
+            'name': name,
+        }
+        return self.do('PUT', '/api/1/accounts/{id}/name', req=req, auth=True)
+
 
 # vi: ft=python
